@@ -3,15 +3,17 @@ import pyppeteer
 import random
 import time
 import json
+import string
 import atexit
+import requests
 
 # Import Detection From Stealth
 from .stealth import stealth
 
-
 class browser:
-    def __init__(self, url, language='en', proxy=None, find_redirect=False, api_url=None):
+    def __init__(self, url, language='en', proxy=None, find_redirect=False, api_url=None, debug=False):
         self.url = url
+        self.debug = debug
         self.proxy = proxy
         self.api_url = api_url
         self.referrer = "https://www.tiktok.com/"
@@ -25,7 +27,7 @@ class browser:
             "--window-position=0,0",
             "--ignore-certifcate-errors",
             "--ignore-certifcate-errors-spki-list",
-             "--user-agent=" + self.userAgent,
+             "--user-agent=" + self.userAgent
         ]
 
         #self.args = []
@@ -55,62 +57,60 @@ class browser:
             loop.run_until_complete(self.start())
 
     async def start(self):
-        try:
-            self.browser = await pyppeteer.launch(self.options)
-            self.page = await self.browser.newPage()
+        self.browser = await pyppeteer.launch(self.options)
+        self.page = await self.browser.newPage()
 
-            await self.page.evaluateOnNewDocument("""() => {
-        delete navigator.__proto__.webdriver;
-            }""")
+        await self.page.evaluateOnNewDocument("""() => {
+    delete navigator.__proto__.webdriver;
+        }""")
 
-            # Check for user:pass proxy
-            if self.proxy != None:
-                if "@" in self.proxy:
-                    await self.page.authenticate({
-                        'username': self.proxy.split("://")[1].split(":")[0],
-                        'password': self.proxy.split("://")[1].split(":")[1].split("@")[0]
-                    })
+        # Check for user:pass proxy
+        if self.proxy != None:
+            if "@" in self.proxy:
+                await self.page.authenticate({
+                    'username': self.proxy.split("://")[1].split(":")[0],
+                    'password': self.proxy.split("://")[1].split(":")[1].split("@")[0]
+                })
 
-            await stealth(self.page)
+        await stealth(self.page)
 
-            # await self.page.emulate({
-            #    'viewport': {'width': random.randint(320, 1920), 'height': random.randint(320, 1920), },
-            #    'deviceScaleFactor': random.randint(1, 3),
-            #    'isMobile': random.random() > 0.5,
-            #    'hasTouch': random.random() > 0.5
-            # })
-            await self.page.goto("https://www.tiktok.com/@floofybastard?lang=" + self.language, {
-                'waitUntil': "load"
-            })
-            self.userAgent = await self.page.evaluate("""() => {return navigator.userAgent; }""")
+        # await self.page.emulate({
+        #    'viewport': {'width': random.randint(320, 1920), 'height': random.randint(320, 1920), },
+        #    'deviceScaleFactor': random.randint(1, 3),
+        #    'isMobile': random.random() > 0.5,
+        #    'hasTouch': random.random() > 0.5
+        # })
 
-            for c in await self.page.cookies():
-                if c['name'] == "s_v_web_id":
-                    self.verifyFp = c['value']
+        # might have to switch to a tiktok url if they improve security
+        await self.page.goto("about:blank", {
+            'waitUntil': "load"
+        })
 
-            if self.verifyFp == None:
-                self.verifyFp = ""
+        self.userAgent = await self.page.evaluate("""() => {return navigator.userAgent; }""")
 
-            self.signature = await self.page.evaluate('''() => {
-            var url = "''' + self.url + "&verifyFp=" + self.verifyFp + '''"
-            var token = window.byted_acrawler.sign({url: url});
-            return token;
-            }''')
+        self.verifyFp = ''.join(random.choice(string.ascii_lowercase + string.ascii_uppercase + string.digits) for i in range(16))
 
-            if self.api_url != None:
-                await self.page.goto(self.url +
-                                    "&verifyFp=" + self.verifyFp +
-                                    "&_signature=" + self.signature, {
-                                        'waitUntil': "load"
-                                    })
+        await self.page.evaluate("() => { " + self.__get_js(proxy=self.proxy) + " }")
+        
+        self.signature = await self.page.evaluate('''() => {
+        var url = "''' + self.url + "&verifyFp=" + self.verifyFp + '''"
+        var token = window.byted_acrawler.sign({url: url});
+        return token;
+        }''')
 
-                self.data = await self.page.content()
-                print(self.data)
-                #self.data = await json.loads(self.data)
+        if self.api_url != None:
+            await self.page.goto(self.url +
+                                "&verifyFp=" + self.verifyFp +
+                                "&_signature=" + self.signature, {
+                                    'waitUntil': "load"
+                                })
 
-            await self.browser.close()
-        except:
-            await self.browser.close()
+            self.data = await self.page.content()
+            print(self.data)
+            #self.data = await json.loads(self.data)
+
+        await self.browser.close()
+        await self.browser.close()
 
     async def find_redirect(self):
         try:
@@ -151,3 +151,15 @@ class browser:
 
         except:
             await self.browser.close()
+
+    def __format_proxy(self, proxy):
+        if proxy != None:
+            return {
+                'http': proxy,
+                'https': proxy
+            }
+        else:
+            return None
+
+    def __get_js(self, proxy=None):
+        return requests.get("https://sf16-muse-va.ibytedtos.com/obj/rc-web-sdk-gcs/acrawler.js", proxies=self.__format_proxy(proxy)).text
\ No newline at end of file
