@@ -94,7 +94,8 @@ class TikTokApi:
                     response.append(t)
 
             if not res['hasMore'] and not first:
-                print("TikTok isn't sending more TikToks beyond this point.")
+                if self.debug:
+                    print("TikTok isn't sending more TikToks beyond this point.")
                 return response
 
             realCount = count-len(response)
@@ -487,24 +488,29 @@ class TikTokApi:
     #
     # No Water Mark
     #
-    def get_Video_No_Watermark_ID(self, video_id, proxy=None):
+    def get_Video_No_Watermark_ID(self, video_id, return_bytes=0, proxy=None):
         video_info = self.getTikTokById(video_id)
         video_url = video_info["itemInfo"]["itemStruct"]["video"]["downloadAddr"]
-        headers = {"User-Agent": "okhttp"}
+        headers = {"User-Agent": "okhttp", "Range": "bytes=1000-80000"}
         video_data = requests.get(video_url, params=None, headers=headers).text
         pos = video_data.find("vid:")
+        if pos == -1:
+            return None
         video_url_no_wm = "https://api2-16-h2.musical.ly/aweme/v1/play/?video_id={" \
                           "}&vr_type=0&is_play_url=1&source=PackSourceEnum_PUBLISH&media_type=4" \
             .format(video_data[pos+4:pos+36])
-
-        headers = {"User-Agent": "okhttp"}
-        video_data_no_wm = requests.get(video_url_no_wm, params=None, headers=headers)
-        return video_data_no_wm.content
+        if return_bytes == 0:
+            return video_url_no_wm
+        else:
+            headers = {"User-Agent": "okhttp"}
+            video_data_no_wm = requests.get(video_url_no_wm, params=None, headers=headers)
+            return video_data_no_wm.content
+            
 
 
-    def get_Video_No_Watermark(self, video_url, proxy=None):
+    def get_Video_No_Watermark(self, video_url, return_bytes=0, proxy=None):
         video_id = video_url.split("/video/")[1].split("?")[0]
-        return self.get_Video_No_Watermark_ID(video_id, proxy=proxy)
+        return self.get_Video_No_Watermark_ID(video_id, return_bytes, proxy=proxy)
 
     #
     # PRIVATE METHODS
@@ -521,3 +527,6 @@ class TikTokApi:
             }
         else:
             return None
+
+    def __get_js(self, proxy=None):
+        return requests.get("https://sf16-muse-va.ibytedtos.com/obj/rc-web-sdk-gcs/acrawler.js", proxies=self.__format_proxy(proxy)).text
